Nion Data
=========

The Nion Data library (used in Nion Swift)
------------------------------------------
NionData is the data library for Nion Swift.

.. start-badges

.. list-table::
    :stub-columns: 1

    * - tests
      - | |linux|
    * - package
      - |version|


.. |linux| image:: https://img.shields.io/travis/nion-software/niondata/master.svg?label=Linux%20build
   :target: https://travis-ci.org/nion-software/niondata
   :alt: Travis CI build status (Linux)

.. |version| image:: https://img.shields.io/pypi/v/niondata.svg
   :target: https://pypi.org/project/niondata/
   :alt: Latest PyPI version

.. end-badges

More Information
----------------

- `Changelog <https://github.com/nion-software/niondata/blob/master/CHANGES.rst>`_
